@@ -78,6 +78,8 @@ class Literal(Identifier):
         XSD.token
     )
 
+    __slots__ = ('_language', '_datatype', '_value')
+
     @property
     def datatype(self):
         return self._datatype
@@ -122,6 +124,7 @@ class Literal(Identifier):
 
     def __new__(cls, value, language=None, datatype=None):
         literal = str.__new__(cls, value)
+        literal._value = value
         literal._language = language
         literal._datatype = datatype
         return literal
